import type * as functions from 'firebase-functions';
import { DatabaseType } from './DatabaseType';
import { type FirebaseFunctionConstructor } from './FirebaseFunction';
import { type FunctionType } from './FunctionType';
import { type PrivateKeys } from './PrivateKeys';
import { type ValidReturnType } from './ValidReturnType';
import { type FirebaseScheduleConstructor } from './FirebaseSchedule';
import { type FirebaseRequestConstructor } from './FirebaseRequest';
export type FirebaseFunctionDescriptor<T extends FunctionType<unknown, ValidReturnType, unknown>> = [FirebaseFunctionConstructor<T>];
export declare namespace FirebaseFunctionDescriptor {
    type Parameters<T extends FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>>> = T extends FirebaseFunctionDescriptor<infer U> ? FunctionType.Parameters<U> : never;
    type ReturnType<T extends FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>>> = T extends FirebaseFunctionDescriptor<infer U> ? FunctionType.ReturnType<U> : never;
    type FlattenParameters<T extends FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>>> = T extends FirebaseFunctionDescriptor<infer U> ? FunctionType.FlattenParameters<U> : never;
    function create<T extends FunctionType<unknown, ValidReturnType, unknown>>(firebaseFunction: FirebaseFunctionConstructor<T>): FirebaseFunctionDescriptor<T>;
}
export type FirebaseRequestDescriptor<T extends FunctionType<unknown, ValidReturnType, Record<string, string>>> = [FirebaseRequestConstructor<T>, void, void];
export declare namespace FirebaseRequestDescriptor {
    type Parameters<T extends FirebaseRequestDescriptor<FunctionType<unknown, ValidReturnType, Record<string, string>>>> = T extends FirebaseRequestDescriptor<infer U> ? FunctionType.Parameters<U> : never;
    type ReturnType<T extends FirebaseRequestDescriptor<FunctionType<unknown, ValidReturnType, Record<string, string>>>> = T extends FirebaseRequestDescriptor<infer U> ? FunctionType.ReturnType<U> : never;
    type FlattenParameters<T extends FirebaseRequestDescriptor<FunctionType<unknown, ValidReturnType, Record<string, string>>>> = T extends FirebaseRequestDescriptor<infer U> ? FunctionType.FlattenParameters<U> : never;
    function create<T extends FunctionType<unknown, ValidReturnType, Record<string, string>>>(firebaseRequest: FirebaseRequestConstructor<T>): FirebaseRequestDescriptor<T>;
}
export type FirebaseFunctions = FirebaseFunctionDescriptor<FunctionType<unknown, ValidReturnType, unknown>> | [string, FirebaseScheduleConstructor] | FirebaseRequestDescriptor<FunctionType<unknown, ValidReturnType, Record<string, string>>> | {
    [key: string]: FirebaseFunctions;
};
export type FirebaseRunnableFunctions = (functions.HttpsFunction & functions.Runnable<unknown>) | functions.CloudFunction<unknown> | functions.HttpsFunction | {
    [key: string]: FirebaseRunnableFunctions;
};
export declare function createFirebaseFunctions(getPrivateKeys: (databaseType: DatabaseType) => PrivateKeys, firebaseFunctions: Record<string, FirebaseFunctions>, debugFirebaseFunctions?: Record<string, FirebaseFunctions>): FirebaseRunnableFunctions;
