"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFirebaseFunctions = exports.FirebaseRequestDescriptor = exports.FirebaseFunctionDescriptor = void 0;
const DatabaseType_1 = require("./DatabaseType");
const FirebaseFunction_1 = require("./FirebaseFunction");
const FirebaseSchedule_1 = require("./FirebaseSchedule");
const FirebaseRequest_1 = require("./FirebaseRequest");
var FirebaseFunctionDescriptor;
(function (FirebaseFunctionDescriptor) {
    function create(firebaseFunction) {
        return [firebaseFunction];
    }
    FirebaseFunctionDescriptor.create = create;
})(FirebaseFunctionDescriptor = exports.FirebaseFunctionDescriptor || (exports.FirebaseFunctionDescriptor = {}));
var FirebaseRequestDescriptor;
(function (FirebaseRequestDescriptor) {
    function create(firebaseRequest) {
        return [firebaseRequest, undefined, undefined];
    }
    FirebaseRequestDescriptor.create = create;
})(FirebaseRequestDescriptor = exports.FirebaseRequestDescriptor || (exports.FirebaseRequestDescriptor = {}));
function createFirebaseFunctions(getPrivateKeys, firebaseFunctions, debugFirebaseFunctions = {}) {
    return {
        debug: createFirebaseFunctionsType(debugFirebaseFunctions, getPrivateKeys, new DatabaseType_1.DatabaseType('debug')),
        ...createFirebaseFunctionsType(firebaseFunctions, getPrivateKeys, new DatabaseType_1.DatabaseType('release'))
    };
}
exports.createFirebaseFunctions = createFirebaseFunctions;
function createFirebaseFunctionsType(firebaseFunctions, getPrivateKeys, databaseType) {
    if (Array.isArray(firebaseFunctions)) {
        if (firebaseFunctions.length === 1)
            return FirebaseFunction_1.FirebaseFunction.create(firebaseFunctions[0], getPrivateKeys);
        if (firebaseFunctions.length === 2)
            return FirebaseSchedule_1.FirebaseSchedule.create(firebaseFunctions[0], () => new firebaseFunctions[1](databaseType));
        if (firebaseFunctions.length === 3)
            return FirebaseRequest_1.FirebaseRequest.create(firebaseFunctions[0]);
    }
    const firebaseRunnableFunctions = {};
    for (const entry of Object.entries(firebaseFunctions))
        firebaseRunnableFunctions[entry[0]] = createFirebaseFunctionsType(entry[1], getPrivateKeys, databaseType);
    return firebaseRunnableFunctions;
}
