"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParameterContainer = void 0;
const Crypter_1 = require("../crypter/Crypter");
const HttpsError_1 = require("../HttpsError");
class ParameterContainer {
    data;
    databaseType;
    constructor(data, getPrivateKeys, logger) {
        const crypter = new Crypter_1.Crypter(getPrivateKeys(data.databaseType).cryptionKeys);
        // Get and decrypt parameters
        if (!('parameters' in data) || typeof data.parameters !== 'string')
            throw (0, HttpsError_1.HttpsError)('invalid-argument', 'Missing parameters in firebase function parameters.', logger);
        this.data = crypter.decryptDecode(data.parameters);
        this.databaseType = data.databaseType;
    }
    parameter(key, builder, logger) {
        logger.log('ParameterContainer.parameter', { key: key, expectedTypes: builder.expectedTypes });
        // Throw error if the data is invalid
        if (typeof this.data !== 'object' || this.data === null)
            throw (0, HttpsError_1.HttpsError)('invalid-argument', `Couldn't get ${key.toString()} from invalid parameters.`, logger);
        // Throw error if key couldn't be found
        if (!(key in this.data) && !builder.expectedTypes.includes('undefined'))
            throw (0, HttpsError_1.HttpsError)('invalid-argument', `No ${key.toString()} in parameters.`, logger);
        const parameter = this.data[key];
        // Throw error if type isn't expected
        if (!builder.expectedTypes.includes(typeof parameter))
            throw (0, HttpsError_1.HttpsError)('invalid-argument', `Parameter ${key.toString()} has an invalid type, expected: ${builder.expectedTypes}, actual: ${typeof parameter}`, logger);
        return builder.build(parameter, logger.nextIndent);
    }
}
exports.ParameterContainer = ParameterContainer;
